Daemon rucio-bb8 — Rucio 1.2 documentation

# Daemon rucio-bb8

    usage: rucio-bb8 [-h] [--dry-run] [--exclude-expression EXCLUDE_EXPRESSION]
                     [--comment COMMENT] [--force-expression FORCE_EXPRESSION]
                     [--decomission] [--priority PRIORITY]
                     [--source-replica-expression SOURCE_REPLICA_EXPRESSION]
                     rse bytes

## Positional Arguments

`rse` | RSE to rebalance
`bytes` | Number of bytes to rebalance

## Named Arguments

`--dry-run` | Only run in dry-run mode Default: False
`--exclude-expression`
| Exclude these rse_expression from being destinations
`--comment` | Add a comment to the new rules
`--force-expression`
| For this rse_expression for rebalanced rules instead of letting BB8 decide
`--decomission` | Run BB8 in decomission mode Default: False
`--priority` | Priority for the newly created rules Default: 3
`--source-replica-expression`
| Source replica expression for the newly created rules